@@ -23,11 +23,12 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include "camel-stub.h"
 
 #include <camel/camel-exception.h>
 #include <camel/camel-operation.h>
-#include <camel/camel-i18n.h>
 
 #include <errno.h>
 #include <string.h>
@@ -162,7 +163,15 @@ connect_to_storage (CamelStub *stub, struct sockaddr_un *sa_un,
 			 */
 			camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL,
 					     "Cancelled");
-		} else {
+		} else if (errno == ENOENT) {
+			/* socket_path has changed, mostly because user name has been changed.
+			 * need to restart evolution for changes to take effect.
+			 */
+			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
+					      _("Could not connect to %s: Please restart Evolution"),
+					      stub->backend_name);
+		}
+		else {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
 					      _("Could not connect to %s: %s"),
 					      stub->backend_name,
@@ -430,7 +439,7 @@ stub_send_internal (CamelStub *stub, CamelException *ex, gboolean oneway,
 				case CAMEL_STUB_ARG_UINT32ARRAY:
 				{
 					GArray **arr = va_arg (ap, GArray **);
-					int i, len, unread_count;
+					guint32 i, len, unread_count;
 					status = camel_stub_marshal_decode_uint32 (stub->cmd, &len);
 					if (status == -1)
 						break;
